@@ -1750,6 +1750,10 @@ class RunAttachmentsAPI:
                 client=self.client,
                 attachment_id=_to_uuid(attachment_id)
             )
+            # Extract bytes from File object returned by generator
+            if response and hasattr(response, 'payload'):
+                file_bytes = response.payload.read()
+                return ApiResponse(data=file_bytes)
             return ApiResponse(data=response)
         except Exception as e:
             return ApiResponse(error=e)
@@ -1771,6 +1775,10 @@ class RunAttachmentsAPI:
                 client=self.client,
                 attachment_id=_to_uuid(attachment_id)
             )
+            # Extract bytes from File object returned by generator
+            if response and hasattr(response, 'payload'):
+                file_bytes = response.payload.read()
+                return ApiResponse(data=file_bytes)
             return ApiResponse(data=response)
         except Exception as e:
             return ApiResponse(error=e)
